Skip to contents

Prints a SeverityEstimateFit object in a structured format. Currently just prints the model_fit slot using the print method for a stanfit object.

Usage

# S3 method for class 'SeverityEstimateFit'
print(x, ...)

Arguments

x

An object of class SeverityEstimateFit.

...

Further arguments passed to the print method for a stanfit object.

Value

x invisibly.