Severity Estimate Fit Class
SeverityEstimateFit.RdThis class contains the output from a severity estimate model fitting.
Slots
model_fitA stanfit object returned from fitting a severity estimate model.
populationThe population data used in model fitting in array form with dimensions corresponding to 'time_period' and 'strata'.
incidenceThe line list data used in model fitting in array form counting incidence with dimensions corresponding to 'time_period', 'strata', 'surveillance', and 'outcome'.
time_periodA data.frame with the variables describing the 'time_period' dimensions of
populationandincidence.strataA data.frame with the variables describing the 'strata' dimensions of
populationandincidence.surveillanceA data.frame with the variables describing the 'surveillance' dimension of
incidence.outcomeA data.frame with the variables describing the 'outcome' dimension of
incidence.