Severity Estimate Model
SeverityEstimateModel.RdA representation of a severity estimate model and its metadata.
Slots
line_listA line list of cases to model the severity of.
populationA dataset containing information on the population broken down by strataification.
strataA list of model stratification specifications.
timestepsA list specifying the timestep column of the linelist.
detectionA list specifying the detection type mapping.
outcomeA list specifying the outcome severity mapping.
active_priorParameters for the beta distribution prior for the active detection rate.
passive_asymptomatic_priorParameters for the beta distribution prior for the passive asymptomatic detection rate.
passive_symptomatic_priorParameters for the beta distribution prior for the passive symptomatic detection rate.