Calculate Fatality Ratio Statistics
calculate_fatality_ratio.RdCalculate a data.frame of fatality ratios broken down by strata, as well
as other optional model metrics.
Usage
calculate_fatality_ratio(x, ...)
# S3 method for class 'SeverityEstimateFit'
calculate_fatality_ratio(
x,
mean_estimate = TRUE,
median_estimate = TRUE,
naive_estimate = FALSE,
alpha = 0.05,
...
)
# Default S3 method
calculate_fatality_ratio(x, ...)Arguments
- x
A object to calculate fatality ratio statistics from, typically a SeverityEstimateFit S4 object.
- ...
Further arguments passed to other methods.
- mean_estimate
A single logical indicating if the mean estimate for the ratios should be included in the '
*_mean_estimate' columns of the returneddata.frame.- median_estimate
A single logical indicating if the median estimate for the ratios should be included in the '
*_median_estimate column of the returneddata.frame.- naive_estimate
A single logical indicating if the naive estimate for fatality ratio should be included in the 'naive
_estimate' column.- alpha
A numeric of significance levels to return the parameters confidence intervals for. The columns will be in '
*_{lower/upper}_{alpha}' format (i.e. '*_lower_05' and '*_upper_05' foralpha=0.05).